@@ -33,7 +33,6 @@
 #include "cpufreq-prefs.h"
 #include "cpufreq-popup.h"
 #include "cpufreq-monitor.h"
-#include "cpufreq-monitor-factory.h"
 #include "cpufreq-utils.h"
 
 struct _CPUFreqApplet {
@@ -74,9 +73,6 @@ struct _CPUFreqAppletClass {
         PanelAppletClass parent_class;
 };
 
-static void     cpufreq_applet_init              (CPUFreqApplet      *applet);
-static void     cpufreq_applet_class_init        (CPUFreqAppletClass *klass);
-
 static void     cpufreq_applet_preferences_cb    (GSimpleAction *action,
                                                   GVariant      *parameter,
                                                   gpointer       user_data);
@@ -940,10 +936,6 @@ cpufreq_applet_setup (CPUFreqApplet *applet)
 	AtkObject      *atk_obj;
 	GSettings *settings;
 
-	g_set_application_name  (_("CPU Frequency Scaling Monitor"));
-
-	gtk_window_set_default_icon_name ("gnome-cpu-frequency-applet");
-
         /* Preferences */
         if (applet->prefs)
                 g_object_unref (applet->prefs);
@@ -965,8 +957,7 @@ cpufreq_applet_setup (CPUFreqApplet *applet)
                           (gpointer) applet);
 
         /* Monitor */
-        applet->monitor = cpufreq_monitor_factory_create_monitor (
-                cpufreq_prefs_get_cpu (applet->prefs));
+        applet->monitor = cpufreq_monitor_new (cpufreq_prefs_get_cpu (applet->prefs));
         cpufreq_monitor_run (applet->monitor);
         g_signal_connect_swapped (G_OBJECT (applet->monitor), "changed",
                                   G_CALLBACK (cpufreq_applet_update),
@@ -1019,7 +1010,7 @@ cpufreq_applet_factory (CPUFreqApplet *applet, const gchar *iid, gpointer gdata)
         return retval;
 }
 
-PANEL_APPLET_OUT_PROCESS_FACTORY ("CPUFreqAppletFactory",
-				  CPUFREQ_TYPE_APPLET,
-				  (PanelAppletFactoryCallback) cpufreq_applet_factory,
-				  NULL)
+PANEL_APPLET_IN_PROCESS_FACTORY ("CPUFreqAppletFactory",
+                                 CPUFREQ_TYPE_APPLET,
+                                 (PanelAppletFactoryCallback) cpufreq_applet_factory,
+                                 NULL)
